package org.orekit.web.doc.examples;

import java.io.IOException;
import java.text.MessageFormat;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.TimeUnit;

import org.eclipse.jetty.websocket.api.Session;
import org.eclipse.jetty.websocket.api.StatusCode;
import org.eclipse.jetty.websocket.api.annotations.OnWebSocketClose;
import org.eclipse.jetty.websocket.api.annotations.OnWebSocketConnect;
import org.eclipse.jetty.websocket.api.annotations.OnWebSocketMessage;
import org.eclipse.jetty.websocket.api.annotations.WebSocket;

@WebSocket
public class ODClientSocket{
	
    private Session session;
    
    //You might have noticed that there is a CountDownLatch that is counted down 
    // when the connection is open. This latch is only for convenience in order 
    // to block other part of the client code before the connection is open. 
    CountDownLatch latch= new CountDownLatch(1);
 
    private final CountDownLatch closeLatch = new CountDownLatch(1);
    
    public boolean awaitClose(int duration, TimeUnit unit) throws InterruptedException {
        return this.closeLatch.await(duration, unit);
    }


    @OnWebSocketMessage
    public void onText(Session session, String message) {
        System.out.println("Message received from server:" + message);
    }
 
    @OnWebSocketConnect
    public void onConnect(Session session) {
        System.out.println("Connected to server");
        this.session=session;
        latch.countDown();
    }
     
    @OnWebSocketClose
    public void onClose(int statusCode, String reason)
    {
    	if (StatusCode.NORMAL == statusCode) {
            System.out.println(MessageFormat.format("Connection closed: {0} - {1}", statusCode, reason));    		
    	}
    	else {
            // Connection closed: 1001 - Idle Timeout
    		 System.out.println(MessageFormat.format("Connection closed: {0} - {1}", statusCode, reason));    		 
    	}
        this.session = null;
        this.closeLatch.countDown(); // trigger latch
        
    }
    
    public void sendMessage(String str) {
        try {
        	if (session != null) {
        		session.getRemote().sendString(str);
        	}
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
     
    public CountDownLatch getLatch() {
        return latch;
    }
}
