/* Copyright 2018-2019 CS Systèmes d'Information
 * Licensed to CS Systèmes d'Information (CS) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * CS licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.orekit.web.json.measgen;

import org.orekit.web.json.GeographicPosition;

public class StationMeasGenRequest extends MeasGenRequest {

	public static class RangeNoise{
		private double sigmaRange = 10.0;

		public double getSigmaRange() {
			return sigmaRange;
		}

		public void setSigmaRange(double sigmaRange) {
			this.sigmaRange = sigmaRange;
		}
	}

	public static class RangeRateNoise{
		private double sigmaRangeRate = 0.001;

		public double getSigmaRangeRate() {
			return sigmaRangeRate;
		}

		public void setSigmaRangeRate(double sigmaRangeRate) {
			this.sigmaRangeRate = sigmaRangeRate;
		}
	}

	public static class AzElNoise{

		private double sigmaAz = 0.0005;
		
		private double sigmaEl = 0.0005;

		public double getSigmaAz() {
			return sigmaAz;
		}

		public void setSigmaAz(double sigmaAz) {
			this.sigmaAz = sigmaAz;
		}

		public double getSigmaEl() {
			return sigmaEl;
		}

		public void setSigmaEl(double sigmaEl) {
			this.sigmaEl = sigmaEl;
		}

	}

	public static class MeasGenStation {

		private String name = "";
		
		private GeographicPosition position;

		
		private double temperature = 273.16 + 18;
		
		private double pressure = 1013.25;
		
		private double rHumidity = 0.5;

		private double minElevation = 0;		

		private boolean generateAzEl = true;
		
		private boolean generateRange = true;
		
		private boolean generateRangeRate = false;
		
		private double genStep = 60;
		
		// ------------------------------------------------------------------------------
		// AzEL
		// ------------------------------------------------------------------------------
		
		private AzElNoise azElNoise;
		
		private double azBias;

		private double elBias;
		
		private boolean azElTropo;
		
		private boolean azElIono;
		
		// ------------------------------------------------------------------------------
		// Range
		// ------------------------------------------------------------------------------
		private boolean rangeTwoWay = false;
		
		private RangeNoise rangeNoise;
		
		private double rangeBias;
		
		private boolean rangeTropo;
		
		private boolean rangeIono;
				
		// ------------------------------------------------------------------------------
		// RangeRate
		// ------------------------------------------------------------------------------
		private boolean rangeRateTwoWay = false;
		
		private RangeRateNoise rangeRateNoise;
		
		private double rangeRateBias;
		
		private boolean rangeRateTropo;
		
		private boolean rangeRateIono;
		
		public String getName() {
			return name;
		}
		public void setName(String name) {
			this.name = name;
		}
		public GeographicPosition getPosition() {
			return position;
		}
		public void setPosition(GeographicPosition position) {
			this.position = position;
		}
		public double getMinElevation() {
			return minElevation;
		}
		public void setMinElevation(double minElevation) {
			this.minElevation = minElevation;
		}
		public boolean isGenerateAzEl() {
			return generateAzEl;
		}
		public boolean isGenerateRangeRate() {
			return generateRangeRate;
		}
		public void setGenerateRangeRate(boolean generateRangeRate) {
			this.generateRangeRate = generateRangeRate;
		}
		public void setGenerateAzEl(boolean generateAzEl) {
			this.generateAzEl = generateAzEl;
		}
		public double getGenStep() {
			return genStep;
		}

		public void setGenStep(double genStep) {
			this.genStep = genStep;
		}
		public AzElNoise getAzElNoise() {
			return azElNoise;
		}
		public void setAzElNoise(AzElNoise azElNoise) {
			this.azElNoise = azElNoise;
		}
		public double getAzBias() {
			return azBias;
		}
		public void setAzBias(double azBias) {
			this.azBias = azBias;
		}
		public double getElBias() {
			return elBias;
		}
		public void setElBias(double elBias) {
			this.elBias = elBias;
		}
		public boolean isAzElTropo() {
			return azElTropo;
		}
		public void setAzElTropo(boolean azElTropo) {
			this.azElTropo = azElTropo;
		}
		public boolean isAzElIono() {
			return azElIono;
		}
		public void setAzElIono(boolean azElIono) {
			this.azElIono = azElIono;
		}
		public boolean isGenerateRange() {
			return generateRange;
		}
		public void setGenerateRange(boolean generateRange) {
			this.generateRange = generateRange;
		}
		public boolean isRangeTwoWay() {
			return rangeTwoWay;
		}
		public void setRangeTwoWay(boolean rangeTwoWay) {
			this.rangeTwoWay = rangeTwoWay;
		}
		public RangeNoise getRangeNoise() {
			return rangeNoise;
		}
		public void setRangeNoise(RangeNoise rangeNoise) {
			this.rangeNoise = rangeNoise;
		}
		public double getRangeBias() {
			return rangeBias;
		}
		public void setRangeBias(double rangeBias) {
			this.rangeBias = rangeBias;
		}
		public boolean isRangeTropo() {
			return rangeTropo;
		}
		public void setRangeTropo(boolean rangeTropo) {
			this.rangeTropo = rangeTropo;
		}
		public boolean isRangeIono() {
			return rangeIono;
		}
		public void setRangeIono(boolean rangeIono) {
			this.rangeIono = rangeIono;
		}
		public boolean isRangeRateTwoWay() {
			return rangeRateTwoWay;
		}
		public void setRangeRateTwoWay(boolean rangeRateTwoWay) {
			this.rangeRateTwoWay = rangeRateTwoWay;
		}
		public RangeRateNoise getRangeRateNoise() {
			return rangeRateNoise;
		}
		public void setRangeRateNoise(RangeRateNoise rangeRateNoise) {
			this.rangeRateNoise = rangeRateNoise;
		}
		public double getRangeRateBias() {
			return rangeRateBias;
		}
		public void setRangeRateBias(double rangeRateBias) {
			this.rangeRateBias = rangeRateBias;
		}
		public boolean isRangeRateTropo() {
			return rangeRateTropo;
		}
		public void setRangeRateTropo(boolean rangeRateTropo) {
			this.rangeRateTropo = rangeRateTropo;
		}
		public boolean isRangeRateIono() {
			return rangeRateIono;
		}
		public void setRangeRateIono(boolean rangeRateIono) {
			this.rangeRateIono = rangeRateIono;
		}
		public double getTemperature() {
			return temperature;
		}
		public void setTemperature(double temperature) {
			this.temperature = temperature;
		}
		public double getPressure() {
			return pressure;
		}
		public void setPressure(double pressure) {
			this.pressure = pressure;
		}
		public double getrHumidity() {
			return rHumidity;
		}
		public void setrHumidity(double rHumidity) {
			this.rHumidity = rHumidity;
		}

	}

	private MeasGenStation[] stations;
	
	private String satName = "";

	private Integer seed = null;	

	private double mu = 3.986004415e14;

	public MeasGenStation[] getStations() {
		return stations;
	}

	public void setStations(MeasGenStation[] stations) {
		this.stations = stations;
	}

	public String getSatName() {
		return satName;
	}

	public void setSatName(String satName) {
		this.satName = satName;
	}

	public Integer getSeed() {
		return seed;
	}

	public void setSeed(Integer seed) {
		this.seed = seed;
	}

	public double getMu() {
		return mu;
	}
	
	public void setMu(double mu) {
		this.mu = mu;
	}


}
