/* Copyright 2018-2019 CS Systèmes d'Information
 * Licensed to CS Systèmes d'Information (CS) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * CS licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.orekit.web.json.od;

import org.orekit.web.json.propagation.NumericalPropagator;

public class Estimator {


	public static class Optimizer {
			
			public static class GaussNewton {
				// no parameters required by the implementation
			}
			
			public static class LevenbergMarquardt {
				private double initialStepBoundFactor = 1.0e6;

				public double getInitialStepBoundFactor() {
					return initialStepBoundFactor;
				}
				public void setInitialStepBoundFactor(double initialStepBoundFactor) {
					this.initialStepBoundFactor = initialStepBoundFactor;
				}
			}
			
			private LevenbergMarquardt levenbergMarquart = new LevenbergMarquardt();
			
			private GaussNewton gaussNewton;
			
			public LevenbergMarquardt getLevenbergMarquart() {
				return levenbergMarquart;
			}
			public void setLevenbergMarquart(LevenbergMarquardt levenbergMarquart) {
				this.levenbergMarquart = levenbergMarquart;
			}
			public GaussNewton getGaussNewton() {
				return gaussNewton;
			}
			public void setGaussNewton(GaussNewton gaussNewton) {
				this.gaussNewton = gaussNewton;
			}
		}
		
		public static class MeasurementsParams {
			private boolean dragCdEstimated = false;
			private boolean solarRadiationPressureCrEstimated = false;
			
			private double rangeOutlierRejectionMultiplier = 6;
			private double rangeRateOutlierRejectionMultiplier = 6;
			private double azElOutlierRejectionMultiplier = 6;
			private double pvOutlierRejectionMultiplier = 6;
			
			private int outliersRejectionStartingIteration = 2;
			
			private double rangeMeasurementsBaseWeight = 1.0;
			
			private double rangeRateMeasurementsBaseWeight = 1.0;

			private double azimuthMeasurementsBaseWeight = 1.0;
			private double elevationMeasurementsBaseWeight = 1.0;
			
			private double pvMeasurementsBaseWeight = 1.0;
			private double pvMeasurementsPositionSigma = 10.0;
			private double pvMeasurementsVelocitySigma = 0.01;
			
			public boolean isDragCdEstimated() {
				return dragCdEstimated;
			}
			public void setDragCdEstimated(boolean dragCdEstimated) {
				this.dragCdEstimated = dragCdEstimated;
			}
			public boolean isSolarRadiationPressureCrEstimated() {
				return solarRadiationPressureCrEstimated;
			}
			public void setSolarRadiationPressureCrEstimated(boolean solarRadiationPressureCrEstimated) {
				this.solarRadiationPressureCrEstimated = solarRadiationPressureCrEstimated;
			}
			public double getRangeOutlierRejectionMultiplier() {
				return rangeOutlierRejectionMultiplier;
			}
			public void setRangeOutlierRejectionMultiplier(double rangeOutlierRejectionMultiplier) {
				this.rangeOutlierRejectionMultiplier = rangeOutlierRejectionMultiplier;
			}
			public double getRangeRateOutlierRejectionMultiplier() {
				return rangeRateOutlierRejectionMultiplier;
			}
			public void setRangeRateOutlierRejectionMultiplier(double rangeRateOutlierRejectionMultiplier) {
				this.rangeRateOutlierRejectionMultiplier = rangeRateOutlierRejectionMultiplier;
			}
			public double getAzElOutlierRejectionMultiplier() {
				return azElOutlierRejectionMultiplier;
			}
			public void setAzElOutlierRejectionMultiplier(double azElOutlierRejectionMultiplier) {
				this.azElOutlierRejectionMultiplier = azElOutlierRejectionMultiplier;
			}
			public double getPvOutlierRejectionMultiplier() {
				return pvOutlierRejectionMultiplier;
			}
			public void setPvOutlierRejectionMultiplier(double pvOutlierRejectionMultiplier) {
				this.pvOutlierRejectionMultiplier = pvOutlierRejectionMultiplier;
			}
			public int getOutliersRejectionStartingIteration() {
				return outliersRejectionStartingIteration;
			}
			public void setOutliersRejectionStartingIteration(int outliersRejectionStartingIteration) {
				this.outliersRejectionStartingIteration = outliersRejectionStartingIteration;
			}
			public double getRangeMeasurementsBaseWeight() {
				return rangeMeasurementsBaseWeight;
			}
			public void setRangeMeasurementsBaseWeight(double rangeMeasurementsBaseWeight) {
				this.rangeMeasurementsBaseWeight = rangeMeasurementsBaseWeight;
			}
			public double getRangeRateMeasurementsBaseWeight() {
				return rangeRateMeasurementsBaseWeight;
			}
			public void setRangeRateMeasurementsBaseWeight(double rangeRateMeasurementsBaseWeight) {
				this.rangeRateMeasurementsBaseWeight = rangeRateMeasurementsBaseWeight;
			}
			public double getAzimuthMeasurementsBaseWeight() {
				return azimuthMeasurementsBaseWeight;
			}
			public void setAzimuthMeasurementsBaseWeight(double azimutMeasurementsBaseWeight) {
				this.azimuthMeasurementsBaseWeight = azimutMeasurementsBaseWeight;
			}
			public double getElevationMeasurementsBaseWeight() {
				return elevationMeasurementsBaseWeight;
			}
			public void setElevationMeasurementsBaseWeight(double elevationMeasurementsBaseWeight) {
				this.elevationMeasurementsBaseWeight = elevationMeasurementsBaseWeight;
			}
			public double getPvMeasurementsBaseWeight() {
				return pvMeasurementsBaseWeight;
			}
			public void setPvMeasurementsBaseWeight(double pvMeasurementsBaseWeight) {
				this.pvMeasurementsBaseWeight = pvMeasurementsBaseWeight;
			}
			public double getPvMeasurementsPositionSigma() {
				return pvMeasurementsPositionSigma;
			}
			public void setPvMeasurementsPositionSigma(double pvMeasurementsPositionSigma) {
				this.pvMeasurementsPositionSigma = pvMeasurementsPositionSigma;
			}
			public double getPvMeasurementsVelocitySigma() {
				return pvMeasurementsVelocitySigma;
			}
			public void setPvMeasurementsVelocitySigma(double pvMeasurementsVelocitySigma) {
				this.pvMeasurementsVelocitySigma = pvMeasurementsVelocitySigma;
			}
		}
		
		private Optimizer optimizer = new Optimizer();
		private NumericalPropagator numericalPropagator;
		private MeasurementsParams measurements = new MeasurementsParams();
		
		private double convergenceThreshold = 1.0e-3;
		private int maxIterationsNumber = 20;
		private int maxEvaluationsNumber = 25;
		
		public NumericalPropagator getNumericalPropagator() {
			return numericalPropagator;
		}
		public void setNumericalPropagator(NumericalPropagator numericalPropagator) {
			this.numericalPropagator = numericalPropagator;
		}
		public MeasurementsParams getMeasurements() {
			return measurements;
		}
		public void setMeasurements(MeasurementsParams measurements) {
			this.measurements = measurements;
		}
		public Optimizer getOptimizer() {
			return optimizer;
		}
		public void setOptimizer(Optimizer optimizer) {
			this.optimizer = optimizer;
		}
		public double getConvergenceThreshold() {
			return convergenceThreshold;
		}
		public void setConvergenceThreshold(double convergenceThreshold) {
			this.convergenceThreshold = convergenceThreshold;
		}
		public int getMaxIterationsNumber() {
			return maxIterationsNumber;
		}
		public void setMaxIterationsNumber(int maxIterationsNumber) {
			this.maxIterationsNumber = maxIterationsNumber;
		}
		public int getMaxEvaluationsNumber() {
			return maxEvaluationsNumber;
		}
		public void setMaxEvaluationsNumber(int maxEvaluationsNumber) {
			this.maxEvaluationsNumber = maxEvaluationsNumber;
		}
		
}
