/* Copyright 2018-2019 CS Systèmes d'Information
 * Licensed to CS Systèmes d'Information (CS) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * CS licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.orekit.web.json.od;

import org.orekit.web.json.GeographicPosition;
import org.orekit.web.json.enums.MeasurementsFileFormat;

public class Measurements {


	public static class MeasurementsStation {

		public static class Bias {
			private double value;
			private double min;
			private double max;
			private boolean estimated;
			
			public double getValue() {
				return value;
			}
			public void setValue(double value) {
				this.value = value;
			}
			public double getMin() {
				return min;
			}
			public void setMin(double min) {
				this.min = min;
			}
			public double getMax() {
				return max;
			}
			public void setMax(double max) {
				this.max = max;
			}
			public boolean isEstimated() {
				return estimated;
			}
			public void setEstimated(boolean estimated) {
				this.estimated = estimated;
			}
		}
	
		public static class Elevation {
			private double sigma;
			private Bias bias;
			private boolean refractionCorrection = false;
			public double getSigma() {
				return sigma;
			}
			public void setSigma(double sigma) {
				this.sigma = sigma;
			}
			public Bias getBias() {
				return bias;
			}
			public void setBias(Bias bias) {
				this.bias = bias;
			}
			public boolean isRefractionCorrection() {
				return refractionCorrection;
			}
			public void setRefractionCorrection(boolean refractionCorrection) {
				this.refractionCorrection = refractionCorrection;
			}
		}
	
		public static class Azimuth {
			private double sigma;
			private Bias bias;
			public double getSigma() {
				return sigma;
			}
			public void setSigma(double sigma) {
				this.sigma = sigma;
			}
			public Bias getBias() {
				return bias;
			}
			public void setBias(Bias bias) {
				this.bias = bias;
			}
		}
	
		public static class Range {
			private double sigma;
			private Bias bias;
			private boolean troposphericCorrection = false;
			public double getSigma() {
				return sigma;
			}
			public void setSigma(double sigma) {
				this.sigma = sigma;
			}
			public Bias getBias() {
				return bias;
			}
			public void setBias(Bias bias) {
				this.bias = bias;
			}
			public boolean isTroposphericCorrection() {
				return troposphericCorrection;
			}
			public void setTroposphericCorrection(boolean troposphericCorrection) {
				this.troposphericCorrection = troposphericCorrection;
			}
		}

		public static class RangeRate {
			private double sigma;
			private Bias bias;
			public double getSigma() {
				return sigma;
			}
			public void setSigma(double sigma) {
				this.sigma = sigma;
			}
			public Bias getBias() {
				return bias;
			}
			public void setBias(Bias bias) {
				this.bias = bias;
			}
		}

		private String name;
		private GeographicPosition geographicPosition;
		private Range range;
		private RangeRate rangeRate;
		private Azimuth azimuth;
		private Elevation elevation;
		
		public String getName() {
			return name;
		}
		public void setName(String name) {
			this.name = name;
		}
		public GeographicPosition getGeographicPosition() {
			return geographicPosition;
		}
		public void setGeographicPosition(GeographicPosition geographicPosition) {
			this.geographicPosition = geographicPosition;
		}
		public Range getRange() {
			return range;
		}
		public void setRange(Range range) {
			this.range = range;
		}
		public RangeRate getRangeRate() {
			return rangeRate;
		}
		public void setRangeRate(RangeRate rangeRate) {
			this.rangeRate = rangeRate;
		}
		public Azimuth getAzimuth() {
			return azimuth;
		}
		public void setAzimuth(Azimuth azimuth) {
			this.azimuth = azimuth;
		}
		public Elevation getElevation() {
			return elevation;
		}
		public void setElevation(Elevation elevation) {
			this.elevation = elevation;
		}
	}

	public static class MeasurementsFile{
		private String requestPartName = "MEASUREMENTS_FILE";
		
		private String format;

		private String fileName = "";

		public String getRequestPartName() {
			return requestPartName;
		}
		public void setRequestPartName(String requestPartName) {
			this.requestPartName = requestPartName;
		}
		public String getFormat() {
			return format;
		}
		public void setFormat(String string) {
			this.format = string;
		}
		public String getFileName() {
			return fileName;
		}
		public void setFileName(String fileName) {
			this.fileName = fileName;
		}
	}
	
	private MeasurementsFile[] files;
	
	private MeasurementsStation[] stations;
	
	public Measurements() {
	}
	
	public MeasurementsFile[] getFiles() {
		return files;
	}
	public void setFiles(MeasurementsFile[] files) {
		this.files = files;
	}
	public MeasurementsStation[] getStations() {
		return stations;
	}
	public void setStations(MeasurementsStation[] stations) {
		this.stations = stations;
	}
	
}
