/* Copyright 2018-2019 CS Systèmes d'Information
 * Licensed to CS Systèmes d'Information (CS) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * CS licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.orekit.web.json.propagation;


public class NumericalPropagator {

	public static class DormandPrince853 {
		private double minStep = 0.001;
		private double maxStep = 300;
		private double positionError = 10.0;
		
		public double getMinStep() {
			return minStep;
		}
		public void setMinStep(double minStep) {
			this.minStep = minStep;
		}
		public double getMaxStep() {
			return maxStep;
		}
		public void setMaxStep(double maxStep) {
			this.maxStep = maxStep;
		}
		public double getPositionError() {
			return positionError;
		}
		public void setPositionError(double positionError) {
			this.positionError = positionError;
		}
	}

	public static class ClassicalRungeKutta {
		private double step;

		public double getStep() {
			return step;
		}

		public void setStep(double step) {
			this.step = step;
		}
	}

	public static class Integrator {
		private DormandPrince853 dormandPrince853 = new DormandPrince853();
		private ClassicalRungeKutta rungeKutta;
		
		public DormandPrince853 getDormandPrince853() {
			return dormandPrince853;
		}
		public void setDormandPrince853(DormandPrince853 dormandPrince853) {
			this.dormandPrince853 = dormandPrince853;
		}
		public ClassicalRungeKutta getRungeKutta() {
			return rungeKutta;
		}
		public void setRungeKutta(ClassicalRungeKutta RungeKutta) {
			this.rungeKutta = RungeKutta;
		}
	}

	private ForceModel forceModel;
	
	private Integrator integrator = new Integrator();
	
	private double positionScale = 10.0;
	
	private double spacecraftMass = 1000; // kg

	public double getSpacecraftMass() {
		return spacecraftMass;
	}

	public void setSpacecraftMass(double spacecraftMass) {
		this.spacecraftMass = spacecraftMass;
	}

	public Integrator getIntegrator() {
		return integrator;
	}

	public void setIntegrator(Integrator integrator) {
		this.integrator = integrator;
	}

	public ForceModel getForceModel() {
		return forceModel;
	}

	public void setForceModel(ForceModel forceModel) {
		this.forceModel = forceModel;
	}

	public double getPositionScale() {
		return positionScale;
	}
	public void setPositionScale(double positionScale) {
		this.positionScale = positionScale;
	}

}
